from setuptools import setup

setup(name='file_deleter',
      version='0.0.2',
      description='Delete all files that match pattern and was created before timepoint.',
      url='https://github.com/estranium/file_deleter',
      author='Dmitry Shevelev',
      author_email='estranium@gmail.com',
      license='MIT',
      packages=['file_deleter'],
      zip_safe=False)
